==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ar.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "وحدة التخزين غير متوفرة ",
    "Storage invalid" : "وحدة تخزين غير صالحه ",
    "Unknown error" : "خطأ غير معروف. ",
    "Could not move %s - File with this name already exists" : "فشل في نقل الملف %s - يوجد ملف بنفس هذا الاسم",
    "Could not move %s" : "فشل في نقل %s",
    "Permission denied" : "تم رفض الاذن ",
    "The target folder has been moved or deleted." : "المجلد المطلوب قد تم نقله او حذفه ",
    "The name %s is already used in the folder %s. Please choose a different name." : "هذا الاسم %s مستخدم مسبقا في المجلد %s . فضلا اختر اسم مختلف .",
    "Error when creating the file" : "خطأ اثناء انشاء الملف ",
    "Error when creating the folder" : "خطأ اثناء انشاء المجلد ",
    "Unable to set upload directory." : "غير قادر على تحميل المجلد",
    "Invalid Token" : "علامة غير صالحة",
    "No file was uploaded. Unknown error" : "لم يتم رفع أي ملف , خطأ غير معروف",
    "There is no error, the file uploaded with success" : "تم ترفيع الملفات بنجاح.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "حجم الملف المرفوع تجاوز قيمة  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The uploaded file was only partially uploaded" : "تم ترفيع جزء من الملفات الذي تريد ترفيعها فقط",
    "No file was uploaded" : "لم يتم ترفيع أي من الملفات",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Failed to write to disk" : "خطأ في الكتابة على القرص الصلب",
    "Not enough storage available" : "لا يوجد مساحة تخزينية كافية",
    "Upload failed. Could not find uploaded file" : "*فشلت علمية الرفع. تعذر إيجاد الملف الذي تم رفعه.\n*فشلت علمية التحميل. تعذر إيجاد الملف الذي تم تحميله.",
    "Upload failed. Could not get file info." : "فشلت عملية الرفع. تعذر الحصول على معلومات الملف.",
    "Invalid directory." : "مسار غير صحيح.",
    "Files" : "الملفات",
    "All files" : "كل الملفات",
    "Favorites" : "المفضلة ",
    "Home" : "البيت",
    "Close" : "إغلاق",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Total file size {size1} exceeds upload limit {size2}" : "حجم الملف الكلي {size1} تجاوز الحد المسموح للرفع {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "لا يوجد مساحة تخزين كافية، انت تقوم برفع {size1} ولكن المساحه المتوفره هي {size2}.",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات .",
    "Could not get result from server." : "تعذر الحصول على نتيجة من الخادم",
    "File upload is in progress. Leaving the page now will cancel the upload." : "عملية رفع الملفات قيد التنفيذ. اغلاق الصفحة سوف يلغي عملية رفع الملفات.",
    "Actions" : "* تطبيقات.\n* أنشطة.",
    "Download" : "تحميل",
    "Rename" : "إعادة التسمية",
    "Delete" : "حذف ",
    "Details" : "تفاصيل",
    "Select" : "اختار",
    "Pending" : "قيد الانتظار",
    "Unable to determine date" : "تعذر تحديد التاريخ",
    "This operation is forbidden" : "هذة العملية ممنوعة ",
    "Error moving file." : "خطأ اثناء نقل الملف ",
    "Error moving file" : "حدث خطأ أثناء نقل الملف",
    "Error" : "خطأ",
    "{new_name} already exists" : "{new_name} موجود مسبقا",
    "Could not rename file" : "لا يستطيع اعادة تسمية الملف",
    "Could not create file" : "لا يستطيع انشاء ملف ",
    "Could not create folder" : "لا يستطيع انشاء مجلد ",
    "Error deleting file." : "خطأ اثناء حذف الملف ",
    "No entries in this folder match '{filter}'" : "لا يوجد مدخلات في هذا المجلد تتوافق مع '{filter}'",
    "Name" : "اسم",
    "Size" : "حجم",
    "Modified" : "معدل",
    "_%n folder_::_%n folders_" : ["لا يوجد مجلدات %n","1 مجلد %n","2 مجلد %n","عدد قليل من مجلدات %n","عدد كبير من مجلدات %n","مجلدات %n"],
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","ملف %n","2 ملف %n","قليل من ملفات %n","الكثير من ملفات %n"," ملفات %n"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم تحميل ملفات %n"],
    "New" : "جديد",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "مساحة تخزين {owner} ممتلئة، لا يمكن تحديث الملفات او مزامنتها بعد الان !",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "المساحة التخزينية لـ {owner} ممتلئة تقريبا ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "مساحتك التخزينية امتلأت تقريبا ",
    "Favorite" : "المفضلة",
    "{newname} already exists" : "{newname} موجود مسبقاً",
    "Upload" : "رفع",
    "Text file" : "ملف نصي",
    "New text file.txt" : "ملف نصي جديد fille.txt",
    "Folder" : "مجلد",
    "New folder" : "مجلد جديد",
    "An error occurred while trying to update the tags" : "حدث خطأ اثناء محاولة تحديث tags",
    "A new file or folder has been <strong>created</strong>" : "تم <strong>  إنشاء</strong> ملف جديد أو مجلد ",
    "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
    "A file or folder has been <strong>deleted</strong>" : "تم <strong>حذف </strong> ملف أو مجلد",
    "A file or folder has been <strong>restored</strong>" : "تم <strong> استعادة </strong> ملف أو مجلد",
    "You created %1$s" : "لقد أنشأت %1$s",
    "%2$s created %1$s" : "%2$s أنشأ %1$s",
    "%1$s was created in a public folder" : "تم إنشاء %1$s في مجلد عام",
    "You changed %1$s" : "لقد غيرت %1$s",
    "%2$s changed %1$s" : "%2$s غير %1$s",
    "You deleted %1$s" : "حذفت %1$s",
    "%2$s deleted %1$s" : "%2$s حذف %1$s",
    "You restored %1$s" : "لقد قمت باستعادة %1$s",
    "%2$s restored %1$s" : "%2$s مستعاد %1$s",
    "%s could not be renamed as it has been deleted" : "%s لا يمكن اعادة تسميته فقد تم حذفه ",
    "%s could not be renamed" : "%s  لا يمكن إعادة تسميته. ",
    "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
    "File handling" : "التعامل مع الملف",
    "Maximum upload size" : "الحد الأقصى لحجم الملفات التي يمكن رفعها",
    "max. possible: " : "الحد الأقصى المسموح به",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "بستخدام PHP-FPM هذه القيمة سوف تحتاج الي 5 دقائق حتي تُتِم عملها بعد الحفظ ",
    "Save" : "حفظ",
    "Can not be edited from here due to insufficient permissions." : "لا يمكن التعديل من هنا نظرا لعدم توفر الصلاحيات الكافيه ",
    "Settings" : "إعدادات",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "استخدم هذا العنوان لـ  <a href=\"%s\" target=\"_blank\">الدخول الى ملفاتك عن طريق WebDAV</a>",
    "Cancel upload" : "إلغاء الرفع",
    "No files in here" : "لا يوجد ملفات هنا ",
    "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Upload too large" : "حجم الترفيع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
    "Files are being scanned, please wait." : "يرجى الانتظار , جاري فحص الملفات .",
    "Currently scanning" : "حالياً يقوم بالفحص",
    "No favorites" : "لا يوجد مفضلات ",
    "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا "
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ar.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "وحدة التخزين غير متوفرة ",
    "Storage invalid" : "وحدة تخزين غير صالحه ",
    "Unknown error" : "خطأ غير معروف. ",
    "Unable to set upload directory." : "غير قادر على تحميل المجلد",
    "Invalid Token" : "علامة غير صالحة",
    "No file was uploaded. Unknown error" : "لم يتم رفع أي ملف , خطأ غير معروف",
    "There is no error, the file uploaded with success" : "تم ترفيع الملفات بنجاح.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "حجم الملف المرفوع تجاوز قيمة  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The uploaded file was only partially uploaded" : "تم ترفيع جزء من الملفات الذي تريد ترفيعها فقط",
    "No file was uploaded" : "لم يتم ترفيع أي من الملفات",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Failed to write to disk" : "خطأ في الكتابة على القرص الصلب",
    "Not enough storage available" : "لا يوجد مساحة تخزينية كافية",
    "The target folder has been moved or deleted." : "المجلد المطلوب قد تم نقله او حذفه ",
    "Upload failed. Could not find uploaded file" : "*فشلت علمية الرفع. تعذر إيجاد الملف الذي تم رفعه.\n*فشلت علمية التحميل. تعذر إيجاد الملف الذي تم تحميله.",
    "Upload failed. Could not get file info." : "فشلت عملية الرفع. تعذر الحصول على معلومات الملف.",
    "Invalid directory." : "مسار غير صحيح.",
    "Files" : "الملفات",
    "All files" : "كل الملفات",
    "Favorites" : "المفضلة ",
    "Home" : "البيت",
    "Close" : "إغلاق",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات .",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Total file size {size1} exceeds upload limit {size2}" : "حجم الملف الكلي {size1} تجاوز الحد المسموح للرفع {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "لا يوجد مساحة تخزين كافية، انت تقوم برفع {size1} ولكن المساحه المتوفره هي {size2}.",
    "Could not get result from server." : "تعذر الحصول على نتيجة من الخادم",
    "File upload is in progress. Leaving the page now will cancel the upload." : "عملية رفع الملفات قيد التنفيذ. اغلاق الصفحة سوف يلغي عملية رفع الملفات.",
    "Actions" : "* تطبيقات.\n* أنشطة.",
    "Download" : "تحميل",
    "Rename" : "إعادة التسمية",
    "Delete" : "حذف ",
    "Unshare" : "إلغاء المشاركة",
    "Details" : "تفاصيل",
    "Select" : "اختار",
    "Pending" : "قيد الانتظار",
    "Unable to determine date" : "تعذر تحديد التاريخ",
    "This operation is forbidden" : "هذة العملية ممنوعة ",
    "No entries in this folder match '{filter}'" : "لا يوجد مدخلات في هذا المجلد تتوافق مع '{filter}'",
    "Name" : "اسم",
    "Size" : "حجم",
    "Modified" : "معدل",
    "_%n folder_::_%n folders_" : ["لا يوجد مجلدات %n","1 مجلد %n","2 مجلد %n","عدد قليل من مجلدات %n","عدد كبير من مجلدات %n","مجلدات %n"],
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","ملف %n","2 ملف %n","قليل من ملفات %n","الكثير من ملفات %n"," ملفات %n"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم تحميل ملفات %n"],
    "New" : "جديد",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "مساحة تخزين {owner} ممتلئة، لا يمكن تحديث الملفات او مزامنتها بعد الان !",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "المساحة التخزينية لـ {owner} ممتلئة تقريبا ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "مساحتك التخزينية امتلأت تقريبا ",
    "Favorite" : "المفضلة",
    "Folder" : "مجلد",
    "New folder" : "مجلد جديد",
    "{newname} already exists" : "{newname} موجود مسبقاً",
    "Upload" : "رفع",
    "An error occurred while trying to update the tags" : "حدث خطأ اثناء محاولة تحديث tags",
    "A new file or folder has been <strong>created</strong>" : "تم <strong>  إنشاء</strong> ملف جديد أو مجلد ",
    "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
    "A file or folder has been <strong>deleted</strong>" : "تم <strong>حذف </strong> ملف أو مجلد",
    "A file or folder has been <strong>restored</strong>" : "تم <strong> استعادة </strong> ملف أو مجلد",
    "You created %1$s" : "لقد أنشأت %1$s",
    "%2$s created %1$s" : "%2$s أنشأ %1$s",
    "%1$s was created in a public folder" : "تم إنشاء %1$s في مجلد عام",
    "You changed %1$s" : "لقد غيرت %1$s",
    "%2$s changed %1$s" : "%2$s غير %1$s",
    "You deleted %1$s" : "حذفت %1$s",
    "%2$s deleted %1$s" : "%2$s حذف %1$s",
    "You restored %1$s" : "لقد قمت باستعادة %1$s",
    "%2$s restored %1$s" : "%2$s مستعاد %1$s",
    "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
    "File handling" : "التعامل مع الملف",
    "Maximum upload size" : "الحد الأقصى لحجم الملفات التي يمكن رفعها",
    "max. possible: " : "الحد الأقصى المسموح به",
    "Save" : "حفظ",
    "Settings" : "إعدادات",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "استخدم هذا العنوان لـ  <a href=\"%s\" target=\"_blank\">الدخول الى ملفاتك عن طريق WebDAV</a>",
    "Cancel upload" : "إلغاء الرفع",
    "No files in here" : "لا يوجد ملفات هنا ",
    "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Upload too large" : "حجم الترفيع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
    "No favorites" : "لا يوجد مفضلات ",
    "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا ",
    "Text file" : "ملف نصي",
    "New text file.txt" : "ملف نصي جديد fille.txt"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
